Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(40)

Unified Diff: sdk/lib/core/regexp.dart

Issue 11783009: Big merge from experimental to bleeding edge. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/core/queue.dart ('k') | sdk/lib/core/sequences.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/core/regexp.dart
diff --git a/sdk/lib/core/regexp.dart b/sdk/lib/core/regexp.dart
index 1bf1b55ea7274303b80cae4bdf414f1c9d34b4f8..a85b0ffb9b3afaf5453c6011ae5fcf28c6ce9f90 100644
--- a/sdk/lib/core/regexp.dart
+++ b/sdk/lib/core/regexp.dart
@@ -62,7 +62,7 @@ abstract class Match {
String get str;
/**
- * The pattern to search for in [str].
+ * The pattern used to search in [str].
*/
Pattern get pattern;
}
@@ -93,10 +93,10 @@ abstract class Match {
abstract class RegExp implements Pattern {
/**
* Constructs a regular expression. The default implementation of a
* [RegExp] sets [multiLine] and [ignoreCase] to false.
*/
external factory RegExp(String pattern, {bool multiLine: false,
- bool ignoreCase: false});
+ bool caseSensitive: true});
/**
* Searches for the first match of the regular expression
@@ -129,10 +129,10 @@ abstract class RegExp implements Pattern {
/**
* Whether this regular expression matches multiple lines.
*/
- bool get multiLine;
+ bool get isMultiLine;
/**
* Whether this regular expression is case insensitive.
*/
- bool get ignoreCase;
+ bool get isCaseSensitive;
}
« no previous file with comments | « sdk/lib/core/queue.dart ('k') | sdk/lib/core/sequences.dart » ('j') | no next file with comments »
@@ -93,10 +93,10 @@ abstract class Match {
/**
* Constructs a regular expression. The default implementation of a
- * [RegExp] sets [multiLine] and [ignoreCase] to false.
+ * [RegExp] sets [multiLine] to false and [caseSensitive] to true.
*/
external factory RegExp(String pattern, {bool multiLine: false,

Powered by Google App Engine
This is Rietveld 408576698